==> sale-3.1.7-2.jar: revenue/sqls/revenue/WaterSearch/gaswaterSearch.sql <==
SELECT
	*
FROM
	(
	SELECT
		w.f_userinfo_id,
		w.f_type,
		isnull( w.f_last_tablebase, 0 ) f_last_tablebase,--上期底数
		isnull( w.f_tablebase, 0 ) f_tablebase,--本期底数
		w.f_pregas,
		w.f_preamount,--应缴金额
		w.f_gas,--实缴气量
		w.f_money,--实缴金额
		w.f_delaypay,--违约金
		w.f_operate_date,--操作时间
		w.f_orgid,--分公司
		w.f_input_date,--录入时间
		a.f_address,
		ui.f_user_name,
		ui.f_userinfo_code
	FROM
		(
		SELECT
			*
		FROM
			(
			SELECT
				h.f_userinfo_id,
				'抄表' AS f_type,
				f_last_tablebase,--上期底数
				f_tablebase,--本期底数
				f_oughtamount AS f_pregas,
				f_oughtfee AS f_preamount,--应缴金额
				isnull( c.f_gas, 0 ) f_gas,--实缴气量
				isnull( c.f_money, 0 ) f_money,--实缴金额
				0 AS f_delaypay,--违约金
				h.f_hand_date AS f_operate_date,--操作时间
				f_input_date,--录入时间
				f_orgid --分公司

			FROM
				t_handplan h
				LEFT JOIN ( SELECT * FROM t_chargeprice WHERE f_state LIKE '有效' ) c ON h.id = c.f_hand_id
			) m UNION ALL
		SELECT
			f_userinfo_id,
			'收费' AS f_type,
			f_last_tablebase,--上期底数
			f_tablebase,--本期底数
			f_pregas,--应交气量
			f_preamount,--应交金额
			f_pregas AS f_gas,--实缴气量
			f_collection AS f_money,--实缴金额
			f_delaypay,--违约金
			f_operate_date,--操作时间
			NULL AS f_input_date,--录入时间
			f_orgid --分公司

		FROM
			t_sellinggas
		WHERE
			f_state = '有效'
		) w
		LEFT JOIN t_userinfo ui ON w.f_userinfo_id = ui.f_userinfo_id
		LEFT JOIN t_userfiles uf ON ui.f_userinfo_id= uf.f_userinfo_id
		LEFT JOIN t_user_address a ON uf.f_useraddress_id= a.id
	) s
WHERE
	{ condition }
ORDER BY
	f_operate_date DESC

==> sale-3.5.4.jar: revenue/sqls/revenue/WaterSearch/gaswaterSearch.sql <==
SELECT
	*
FROM
	(
	SELECT
		w.f_userinfo_id,
		w.f_type,
		{entity.findDialect()==$SqlServer$: $isnull$,$NVL$}( w.f_last_tablebase, 0 ) f_last_tablebase,--上期底数
		{entity.findDialect()==$SqlServer$: $isnull$,$NVL$}( w.f_tablebase, 0 ) f_tablebase,--本期底数
		w.f_pregas,
		w.f_preamount,--应缴金额
		w.f_gas,--实缴气量
		w.f_money,--实缴金额
		w.f_delaypay,--违约金
		w.f_operate_date,--操作时间
		w.f_orgid,--分公司
		w.f_input_date,--录入时间
		a.f_address,
		ui.f_user_name,
		ui.f_userinfo_code
	FROM
		(
		SELECT
			*
		FROM
			(
			SELECT
				h.f_userinfo_id,
				'抄表' AS f_type,
				f_last_tablebase,--上期底数
				f_tablebase,--本期底数
				f_oughtamount AS f_pregas,
				f_oughtfee AS f_preamount,--应缴金额
				{entity.findDialect()==$SqlServer$: $isnull$,$NVL$}( c.f_gas, 0 ) f_gas,--实缴气量
				{entity.findDialect()==$SqlServer$: $isnull$,$NVL$}( c.f_money, 0 ) f_money,--实缴金额
				0 AS f_delaypay,--违约金
				h.f_hand_date AS f_operate_date,--操作时间
				f_input_date,--录入时间
				f_orgid --分公司

			FROM
				t_handplan h
				LEFT JOIN ( SELECT * FROM t_chargeprice WHERE f_state LIKE '有效' ) c ON h.id = c.f_hand_id
			) m UNION ALL
		SELECT
			f_userinfo_id,
			'收费' AS f_type,
			f_last_tablebase,--上期底数
			f_tablebase,--本期底数
			f_pregas,--应交气量
			f_preamount,--应交金额
			f_pregas AS f_gas,--实缴气量
			f_collection AS f_money,--实缴金额
			f_delaypay,--违约金
			f_operate_date,--操作时间
			NULL AS f_input_date,--录入时间
			f_orgid --分公司

		FROM
			t_sellinggas
		WHERE
			f_state = '有效'
		) w
		LEFT JOIN t_userinfo ui ON w.f_userinfo_id = ui.f_userinfo_id
		LEFT JOIN t_userfiles uf ON ui.f_userinfo_id= uf.f_userinfo_id
		LEFT JOIN t_user_address a ON uf.f_useraddress_id= a.id
	) s
WHERE
	{ condition }
ORDER BY
	f_operate_date DESC
